[![License](https://img.shields.io/badge/License-Apache%202.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)
[![Coverage Status](https://coveralls.io/repos/github/Vizgen/vpt-plugin-watershed/badge.svg?t=2ISBNa)](https://coveralls.io/github/Vizgen/vpt-plugin-watershed)

# Vizgen Post-processing Tool Watershed Plugin

The Vizgen Post-processing Tool (VPT) enables users to reprocess and refine the single-cell results of MERSCOPE experiments. 
VPT is a command line tool that emphasizes scalable, reproducible analysis, and can be run on a workstation, a cluster, or 
be deployed in a cloud computing environment.

## Documentation

[User Guide](https://vizgen.github.io/vizgen-postprocessing/)

## Feedback

If you encounter issues or bugs, let us know by [submitting an issue!](https://github.com/Vizgen/vizgen-postprocessing/issues)
Please include:

- A quick issue summary
- Steps that caused it to occur
- The exception generated by the code, if applicable
- Specific lines of code, if indicated in the error message


If you have any other feedback or issues, please reach out to your regional Vizgen field application scientist and CC: Vizgen 
Tech Support at techsupport@vizgen.com.

Please include VPT in your subject line along with the above information in the body.

## Contributing & Code of Conduct

We welcome code contributions! Please refer to the [contribution guide](CONTRIBUTING.md) before getting started.

## Authors

- [Vizgen](https://vizgen.com/)

![Logo](https://vizgen.com/wp-content/uploads/2022/12/Vizgen-Logo_Vizgen-BlackColor-.png)

## License

   Copyright 2022 Vizgen, Inc. All Rights Reserved
   
   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
